@@ -1,17 +1,16 @@
 #[macro_use]
 extern crate log;
 
-pub mod build;
-pub mod init;
-pub mod preprocessors;
-pub mod serve;
+pub mod cmd;
+pub mod renderer;
 pub mod utils;
-pub mod watch;
+pub mod zk;
 
-pub use crate::{build::build, init::init, serve::serve};
+#[doc(inline)]
+pub use crate::{cmd::build, cmd::init, cmd::serve, zk::load_zk};
 
 pub const SRC_DIR: &str = "notes";
 pub const BUILD_DIR: &str = "html";
 pub const CONFIG_FILE: &str = "mdzk.toml";
 pub const SUMMARY_FILE: &str = ".mdzk_summary.md";
-pub const DEFAULT_ZK_TITLE: &str = "My mdzk";
+pub const DEFAULT_ZK_TITLE: &str = "My mdzk";
\ No newline at end of file
